@@ -1,6 +1,4 @@
-from __future__ import absolute_import
-
-import decimal
+from collections.abc import Sequence
 
 from plotly import exceptions
 from plotly.colors import (
@@ -22,11 +20,6 @@ from plotly.colors import (
     validate_scale_values,
 )
 
-try:
-    from collections.abc import Sequence
-except ImportError:
-    from collections import Sequence
-
 
 def is_sequence(obj):
     return isinstance(obj, Sequence) and not isinstance(obj, str)
