@@ -1,6 +1,7 @@
 import sys
+from typing import TYPE_CHECKING
 
-if sys.version_info < (3, 7):
+if sys.version_info < (3, 7) or TYPE_CHECKING:
     from ._dimension import Dimension
     from ._domain import Domain
     from ._labelfont import Labelfont
@@ -9,14 +10,16 @@ if sys.version_info < (3, 7):
     from ._rangefont import Rangefont
     from ._stream import Stream
     from ._tickfont import Tickfont
+    from ._unselected import Unselected
     from . import legendgrouptitle
     from . import line
+    from . import unselected
 else:
     from _plotly_utils.importers import relative_import
 
     __all__, __getattr__, __dir__ = relative_import(
         __name__,
-        [".legendgrouptitle", ".line"],
+        [".legendgrouptitle", ".line", ".unselected"],
         [
             "._dimension.Dimension",
             "._domain.Domain",
@@ -26,5 +29,6 @@ else:
             "._rangefont.Rangefont",
             "._stream.Stream",
             "._tickfont.Tickfont",
+            "._unselected.Unselected",
         ],
     )
