@@ -8,5 +8,5 @@ class VisibleValidator(_plotly_utils.basevalidators.EnumeratedValidator):
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
             values=kwargs.pop("values", [True, False, "legendonly"]),
-            **kwargs
+            **kwargs,
         )
