@@ -6,11 +6,11 @@ class SeparatethousandsValidator(_plotly_utils.basevalidators.BooleanValidator):
         self,
         plotly_name="separatethousands",
         parent_name="choropleth.colorbar",
-        **kwargs
+        **kwargs,
     ):
         super(SeparatethousandsValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
-            **kwargs
+            **kwargs,
         )
