@@ -6,12 +6,12 @@ class SizeValidator(_plotly_utils.basevalidators.NumberValidator):
         self,
         plotly_name="size",
         parent_name="densitymapbox.colorbar.tickfont",
-        **kwargs
+        **kwargs,
     ):
         super(SizeValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
             min=kwargs.pop("min", 1),
-            **kwargs
+            **kwargs,
         )
