@@ -9,5 +9,5 @@ class FillValidator(_plotly_utils.basevalidators.NumberValidator):
             edit_type=kwargs.pop("edit_type", "calc"),
             max=kwargs.pop("max", 1),
             min=kwargs.pop("min", 0),
-            **kwargs
+            **kwargs,
         )
