@@ -7,5 +7,5 @@ class LonValidator(_plotly_utils.basevalidators.NumberValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "plot"),
-            **kwargs
+            **kwargs,
         )
