@@ -10,6 +10,5 @@ class DtickValidator(_plotly_utils.basevalidators.AnyValidator):
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
             implied_edits=kwargs.pop("implied_edits", {"tickmode": "linear"}),
-            role=kwargs.pop("role", "style"),
-            **kwargs
+            **kwargs,
         )
