@@ -10,5 +10,5 @@ class SizeValidator(_plotly_utils.basevalidators.NumberValidator):
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "style"),
             min=kwargs.pop("min", 0),
-            **kwargs
+            **kwargs,
         )
